<?php /*

Diesel 1.0 classes

diesel/system/classes.php
Creation date/cr le: 13/02/2005
Written by/crit par Bigue Nique (BigueNique@yahoo.ca)
Copyright (C) 2005, Fiat+/Lux Media
This file is part of the Diesel Project.
Ce fichier fait partie du projet Diesel.

*/

define("err_regfilenotfound",1);
define("err_regcantopenfile",2);
define("err_regcantreadfile",3);
define("err_reginvalidkey", 4);
define("err_regcantwritefile", 5);

class diesel_error_handler {

 var $no;
 var $comment;
 
 function set($new_no, $new_comment=null) {
  $this->no = (int) $new_no;
  $this->comment = (string) $new_comment;
 }
 
 function no() {
  return (int) $this->no;
 }
 
 function msg() {
  $err = "Undocumented error!";
  switch ($this->no) {
   case err_regfilenotfound: $err = "Registry file does not exist"; break;
   case err_regcantopenfile: $err = "Unable to open registry file"; break;
   case err_regcantreadfile: $err = "Unable to read registry file"; break;
   case err_reginvalidkey: $err = "Invalid registry key"; break;
   case err_regcantwritefile: $err = "Unable to write registry file"; break;
  }
   
  if ($this->comment)
   return "DIESEL ERROR #" . $this->no . ": ". $err . " (".$this->comment.")";
  else
   return "DIESEL ERROR #" . $this->no . ": ". $err;
 }
}

class diesel_registry {

 var $error;
 var $registry_file_path;
 var $data;
 var $modified;
 
 function diesel_registry($_registry_file_path) // constructor
 {
  $this->registry_file_path = $_registry_file_path;
  $this->error = new diesel_error_handler;
 }

 function wake() {
  if (!file_exists($this->registry_file_path)) 
  {
   $this->error->set(err_regfilenotfound, $this->registry_file_path);
   return false;
  }
  else 
  {
   if (!($handle = fopen($this->registry_file_path, 'r'))) 
   {
    $this->error->set(err_regcantopenfile, $this->registry_file_path);
    return false;
   }
   else 
   {
    if (!($read = fread($handle, filesize($this->registry_file_path)))) 
    {
     fclose($handle);
     $this->error->set(err_regcantreadfile, $this->registry_file_path);
     return false;
    }
    else 
    {
     fclose($handle);
     $this->data = unserialize($read);
    }
   }
  }
  $this->modified=false;
  return true;
 }
 
 function sleep() //destructor
 {
  if ($this->modified) {
   if (!($handle=fopen($this->registry_file_path, "w"))) 
   {
    $this->error->set(err_regcantwritefile);
    return false;
   }
   else
   {
    fwrite($handle,serialize($this->data));
    fclose($handle);
    unset($this);
   }
  }
  return true;
 }
 
 function get_value($key)
 {
  $pointer =& $this->data;
  $path = explode('/', $key);
  foreach ($path as $key_name)
  {
   if (isset($pointer[$key_name]))
    $pointer =& $pointer[$key_name];
   else
   {
    $this->error->set(err_reginvalidkey, $key);
    return null;
   }
  }

  return $pointer;
 }
 
 function set_value($key, $value)
 {
  $pointer =& $this->data;
  $path = explode('/', $key);
  foreach ($path as $key_name)
  {
   if (!isset($pointer[$key_name]))
   {
    $pointer[$key_name] = null; //create key
    $this->modified = true;
   }
   $pointer =& $pointer[$key_name];
  }

  if ($pointer != $value) 
  {
   $pointer = $value;
   $this->modified = true;
  }
 }
 
 function delete_key($key)
 {
  $pointer =& $this->data;
  $previous = null;
  $path = explode('/', $key);
  foreach ($path as $key_name)
  {
   if (isset($pointer[$key_name]))
   {
    $previous =& $pointer;
    $pointer =& $pointer[$key_name];
   }
   else
   {
    $this->error->set(err_reginvalidkey, $key);
    return null;
   }
  }

  if ($previous)
  {
   unset($previous[$key_name]);
   $this->modified = true;
   return true;
  }
  else
  {
   $this->error->set(err_reginvalidkey, $key);
   return null;
  }
 }
 
 
} 

class diesel_module {

}

class diesel_engine {

 var $error; // diesel_error_handler object
 var $systempath; 	// string
 var $confpath; 	// string
 var $basepath;		// string
 
 var $modules_defs;
 var $loaded_modules;
 var $sysconf;
 var $siteconf;
 
 function diesel_engine($confpath, $basepath)
 {
  $this->systempath=dirname(__FILE__).'/';
  $this->confpath=$confpath;
  $this->basepath=$basepath; 
 
  // Load configuration file
  include ($this->confpath.'diesel.conf');
  // Load phptools.php
  include_once ($this->systempath.'phptools.php');
  // Load Debug services
  include ($this->systempath.'debug.php');
  global $DEBUG;
  $DEBUG =& new debug();
 // Load database library
 include ($this->systempath.'db.php');
 diesel_db_connect(); // Connect to the database
 // Load user library
 include ($this->systempath.'user.php');
 diesel_session_recall(); // Retrieve session data & authenticates if logged in
 // Load language library
 include ($this->systempath.'lang.php');
 // Load display library
 include ($this->systempath.'display.php');
 }
 
}



?>